Stan Math Library: stan/math/prim/scal/fun/log_rising_factorial.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log_rising_factorial.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_LOG_RISING_FACTORIAL_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_LOG_RISING_FACTORIAL_HPP
3
4 #include <boost/math/special_functions/gamma.hpp>
5
6 namespace stan {
7 namespace math {
8
39 template<typename T1, typename T2>
40 inline typename boost::math::tools::promote_args<T1, T2>::type
41 log_rising_factorial(const T1 x, const T2 n) {
42 using boost::math::lgamma;
43 return lgamma(x + n) - lgamma(x);
44 }
45
46 }
47 }
48
49 #endif
stan::math::lgamma
fvar< T > lgamma(const fvar< T > &x)
Definition: lgamma.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::log_rising_factorial
fvar< T > log_rising_factorial(const fvar< T > &x, const fvar< T > &n)
Definition: log_rising_factorial.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.